Module build

Module build 

standard-plugin build: cargo builds the crate for wasm32-wasip2 (whose output is already a component), the component is copied into the bundle under the manifest’s module name, and the browser artifact is transpiled when jco is installed.

Structs

Built
What a build produced.

Constants

TARGET

Functions

build
Builds one plugin.