pub fn inspect(bytes: &[u8]) -> Result<ComponentShape, String>Expand description
Reads a component’s top-level imports and exports. An error names why the bytes are not a component.
pub fn inspect(bytes: &[u8]) -> Result<ComponentShape, String>Reads a component’s top-level imports and exports. An error names why the bytes are not a component.