pub enum SdkSource {
Path(PathBuf),
Version(String),
}Expand description
Where the SDK comes from in a new crate’s Cargo.toml.
Variants
Implementations
Sourceimpl SdkSource
impl SdkSource
Sourcepub fn default_for_this_build() -> Self
pub fn default_for_this_build() -> Self
The SDK this CLI was built beside when it runs from a Standard Code checkout that still has it, else the crates.io release line of this CLI (the SDK and CLI share one version).